Package: qkiosk
Type: Package
Title: 'QUANTkiosk' API Client
Version: 0.2.31
Imports: curl, jsonlite, stringdist, zoo
Depends: xts
Suggests: fansi
LazyData: yes
Date: 2026-04-22
Authors@R: person(given = c("Jeffrey", "A."), family = "Ryan", role = c("aut", "cre"), email = "jeff@quantkiosk.com", comment=c(ORCID="0009-0003-3627-7896"))
Maintainer: Jeffrey A. Ryan <jeff@quantkiosk.com>
Description: Provide access to 'QUANTkiosk' platform of regulatory and corporate data relevant to financial markets including point-in-time fundamentals, ownership and symbology.
License: GPL-3
URL: https://quantkiosk.com/, https://github.com/quantkiosk/qkiosk-r
BugReports: https://github.com/quantkiosk/qkiosk-r/issues
NeedsCompilation: no
Packaged: 2026-04-22 15:45:49 UTC; jeffreyryan
Author: Jeffrey A. Ryan [aut, cre] (ORCID:
    <https://orcid.org/0009-0003-3627-7896>)
Repository: CRAN
Date/Publication: 2026-04-24 18:20:02 UTC
Built: R 4.5.2; ; 2026-04-24 20:38:28 UTC; unix
