\name{qkiosk-package}
\alias{qkiosk-package}
\alias{qkiosk}
\alias{qk_fund}
\alias{qk_clearcache}
\docType{package}
\title{
\packageTitle{qkiosk}
}
\description{
\packageDescription{qkiosk}
}
\details{

The DESCRIPTION file:
\packageDESCRIPTION{qkiosk}
\packageIndices{qkiosk}

Official QUANTkiosk R API
}
\author{
\packageAuthor{qkiosk}

Maintainer: \packageMaintainer{qkiosk}
}
\references{
\sQuote{http://quantkiosk.com}
}
\keyword{ package }
